@@ -17,7 +17,7 @@ import socket
 import threading
 
 from .aes_encrypt import AESEncrypt
-from .utils import utcnow
+from . import utils
 
 refresh_thread = None
 service_data = {}
@@ -45,14 +45,19 @@ class ServiceRegistry(object):
     def register(self, resource_endpoints, service_name=None,
                  instance_id=socket.gethostname(), tcp_port=None):
         global service_data
+        try:
+            ipv4 = socket.gethostbyname(instance_id)
+        except socket.gaierror:
+            ipv4 = None
         service_data['info'] = dict(
-            endpoints=resource_endpoints,
-            ipv4=socket.gethostbyname(socket.gethostname()),
+            endpoints=resource_endpoints, ipv4=ipv4,
             port=tcp_port or self.config.PORT,
             public_url=self.config.PUBLIC_URL,
-            created=utcnow().replace(microsecond=0).isoformat())
+            created=utils.utcnow().replace(microsecond=0).isoformat())
         service_data['name'] = service_name or self.config.SERVICE_NAME
         service_data['id'] = instance_id
+        logging.info(dict(action='service.register', id=instance_id,
+                          name=service_data['name'], **service_data['info']))
         refresh_thread = threading.Timer(1, ServiceRegistry.update, ())
         refresh_thread.start()
 
@@ -95,7 +100,6 @@ class ServiceRegistry(object):
                              (instance, str(ex)))
             if not info.get('endpoints'):
                 continue
-            logging.info(dict(step=1, instance=instance, **info))
             for resource in info['endpoints']:
                 if resource not in url_map:
                     url_map[resource] = info[
